
# Analyse de l'épidémie de choléra à Soho (1854)

Ce projet recrée la célèbre carte réalisée par John Snow en 1854, montrant la répartition des décès dus au choléra dans le quartier de Soho à Londres. L'objectif est de reproduire cette carte à l'aide de données géographiques historiques, tout en explorant des méthodes modernes de visualisation pour mieux comprendre l'épidémie.

## Contexte historique

En 1854, le quartier de Soho à Londres a été frappé par une épidémie de choléra, qui a causé la mort de 616 personnes. L’épidémie est devenue célèbre en raison des travaux de John Snow, un médecin qui a démontré que le choléra était transmis par l'eau et non par l'air, contrairement à la théorie dominante de l'époque. Son analyse repose sur une carte dans laquelle il a localisé les décès et les pompes à eau publiques de Soho.

## Objectifs du projet

L'objectif de ce projet est de reproduire et d'enrichir l'analyse historique de John Snow à travers la création d'une carte interactive. Nous avons suivi les étapes suivantes pour recréer cette analyse :

1. **Représentation des lieux de décès :** Nous avons utilisé des symboles de tailles proportionnelles pour indiquer les emplacements des décès dus au choléra, selon les données disponibles.
   
2. **Localisation des pompes à eau :** Nous avons ajouté sur la carte les emplacements des pompes à eau publiques, en utilisant un symbole distinct pour les différencier des lieux de décès.

3. **Analyse de la densité des décès :** Nous avons calculé et visualisé la densité des décès pour mettre en évidence la concentration autour de la pompe de Broad Street.

## Description du projet

Ce projet se compose des étapes suivantes :

### 1. **Chargement des données**
   - Nous avons utilisé des fichiers **Shapefile** pour charger les données géographiques des décès dus au choléra et des pompes à eau publiques dans Soho en 1854.
   
### 2. **Conversion des coordonnées**
   - Les données géographiques sont en système de coordonnées British National Grid (EPSG:27700). Nous avons effectué une conversion vers le système WGS 84 (EPSG:4326) pour pouvoir les afficher correctement sur une carte interactive.

### 3. **Création de la carte interactive**
   - À l'aide de la bibliothèque **Folium**, nous avons créé une carte interactive affichant les lieux des décès et des pompes à eau. Les cercles rouges représentent les décès, et les marqueurs bleus indiquent les pompes à eau.

### 4. **Analyse de la densité des décès**
   - Nous avons utilisé une **heatmap** pour visualiser la concentration des décès autour de certaines pompes, notamment la pompe de Broad Street, afin de souligner son rôle central dans l'épidémie.

## Résultats

- La carte interactive montre les lieux des décès et les pompes à eau publiques. Les cercles rouges sont proportionnels au nombre de décès.
- La carte de chaleur (heatmap) met en évidence la concentration des décès autour de la pompe de Broad Street, ce qui confirme l'hypothèse de John Snow selon laquelle la pompe était au centre de l’épidémie.

## Conseils techniques

- **Python / Jupyter Notebook :** Pour ce projet, nous avons utilisé **Python** dans un environnement Jupyter Notebook, avec des bibliothèques comme **GeoPandas** pour la gestion des données géographiques et **Folium** pour la création des cartes interactives.
  
- **Folium** permet de créer des cartes interactives basées sur **OpenStreetMap**, ce qui est une bonne alternative gratuite aux services comme Google Maps.

## Instructions pour l'exécution

1. **Prérequis :**
   - Python 3.x
   - Bibliothèques nécessaires : `geopandas`, `folium`, `matplotlib`, `shapely`, `pandas`, `numpy`, etc.
   - Les fichiers de données **Cholera_Deaths.shp** et **Pumps.shp** doivent être disponibles dans le même répertoire que ce projet.

2. **Installation des bibliothèques :**
   - Pour installer les bibliothèques nécessaires, exécutez la commande suivante dans votre terminal :

     ```bash
     pip install geopandas folium matplotlib shapely pandas numpy
     ```

3. **Exécution du notebook :**
   - Ouvrez le notebook Jupyter et exécutez les cellules pour voir les résultats. La carte interactive sera générée et affichée directement dans le notebook.

4. **Exportation en HTML :**
   - Le fichier **exercice_fr.html** contient les résultats de l'analyse sous forme de carte interactive. Vous pouvez l'ouvrir dans un navigateur pour visualiser les cartes.

## Conclusion

Ce projet permet de recréer et d'enrichir l'analyse historique de John Snow sur l’épidémie de choléra à Soho en 1854. Grâce à la visualisation moderne des données géospatiales, nous pouvons mieux comprendre l'impact de la pompe de Broad Street et la répartition des décès dus au choléra. Ce travail illustre l'importance de l'analyse géospatiale dans les épidémies et comment les outils modernes peuvent aider à mieux comprendre les événements historiques.

## Auteur

- **Victor Gérenton**

